@@ -101,7 +101,7 @@ func TestParseArgs(t *testing.T) {
 		want *cliOptions
 	}{
 		{
-			args: []string{TOOLNAME}, // arg[0] is the command itself
+			args: []string{toolname}, // arg[0] is the command itself
 			want: &cliOptions{
 				Host:               DefaultHost,
 				LogLevel:           DefaultLogLevel,
@@ -112,7 +112,7 @@ func TestParseArgs(t *testing.T) {
 			},
 		},
 		{
-			args: []string{TOOLNAME, "zapp.brannigan.net:27018/samples", "--help"},
+			args: []string{toolname, "zapp.brannigan.net:27018/samples", "--help"},
 			want: nil,
 		},
 	}
