@@ -9,8 +9,8 @@ CREATE TABLE checksum (
  boundaries char(64)     NOT NULL,
  this_crc   char(40)     NOT NULL,
  this_cnt   int          NOT NULL,
- master_crc char(40)         NULL,
- master_cnt int              NULL,
+ source_crc char(40)         NULL,
+ source_cnt int              NULL,
  ts         timestamp    NOT NULL,
  PRIMARY KEY (db, tbl, chunk)
 );
